@@ -62,10 +62,10 @@ func goFieldName(jsonPropName string) string {
 // parsePropertyType takes the JSON value of a property field and extracts
 // the Go type of the property. For example, given this map:
 //
-//  {
-//    "type": "string",
-//    "description": "The command to execute."
-//  },
+//	{
+//	  "type": "string",
+//	  "description": "The command to execute."
+//	},
 //
 // It will emit "string".
 func parsePropertyType(propValue map[string]interface{}) string {
@@ -132,8 +132,8 @@ func parsePropertyType(propValue map[string]interface{}) string {
 //
 // Example:
 //
-//    "allOf": [ { "$ref": "#/definitions/ProtocolMessage" },
-//               {... type description ...} ]
+//	"allOf": [ { "$ref": "#/definitions/ProtocolMessage" },
+//	           {... type description ...} ]
 //
 // Returns base type ProtocolMessage and a map representing type description.
 // If there is no "allOf", returns an empty baseTypeName and descMap itself.
@@ -318,8 +318,13 @@ func emitToplevelType(typeName string, descJson json.RawMessage) string {
 			} else {
 				jsonTag += ",omitempty\"`"
 			}
-
+			if typeName == "Breakpoint" && goType == "Source" {
+				// Make the Source field in Breakpoint a pointer since a DAP client may distinguish
+				// between zero and nil source values.
+				goType = "*" + goType
+			}
 			fmt.Fprintf(&b, "\t%s %s %s\n", goFieldName(propName), goType, jsonTag)
+
 		}
 	}
 
