@@ -15,6 +15,7 @@
 package dap
 
 import (
+	"encoding/json"
 	"reflect"
 	"testing"
 )
@@ -132,10 +133,10 @@ var configurationDoneResponseStruct = ConfigurationDoneResponse{Response: *newRe
 
 // -------- Launch
 
-var launchRequestString = `{"seq":3,"type":"request","command":"launch","arguments":{"noDebug": true,"name":"Launch"}}`
+var launchRequestString = `{"seq":3,"type":"request","command":"launch","arguments":{"noDebug":true,"name":"Launch"}}`
 var launchRequestStruct = LaunchRequest{
 	Request:   *newRequest(3, "launch"),
-	Arguments: map[string]interface{}{"noDebug": true, "name": "Launch"},
+	Arguments: json.RawMessage(`{"noDebug":true,"name":"Launch"}`),
 }
 
 var launchResponseString = `{"seq":3,"type":"response","request_seq":4,"command":"launch","success":true}`
@@ -146,7 +147,7 @@ var launchResponseStruct = LaunchResponse{Response: *newResponse(3, 4, "launch",
 var attachRequestString = `{"seq":4,"type":"request","command":"attach","arguments":{}}`
 var attachRequestStruct = AttachRequest{
 	Request:   *newRequest(4, "attach"),
-	Arguments: map[string]interface{}{},
+	Arguments: json.RawMessage(`{}`),
 }
 
 var attachResponseString = `{"seq":4,"type":"response","request_seq":5,"command":"attach","success":true}`
@@ -951,8 +952,10 @@ func Test_DecodeProtocolMessage(t *testing.T) {
 				if test.wantErr != "" { // Did we expect one?
 					t.Errorf("got error=nil, want %#q", test.wantErr)
 				}
+				got, _ := json.Marshal(msg)
+				want, _ := json.Marshal(test.wantMsg)
 				if !reflect.DeepEqual(msg, test.wantMsg) { // Check result
-					t.Errorf("\ngot message\n%+v\nwant\n%+v", msg, test.wantMsg)
+					t.Errorf("\ngot message\n%s\nwant\n%s", got, want)
 				}
 			}
 		})
